export const CAUSE = {
  TYPE: "type",
  UNDEFINED: "undefined",
  NULL: "null",
  EMPTY_STRING: "empty-string",
  ONLY: "only",
  CONVERTER: "converter",
  MIN_VALUE: "min-value",
  MAX_VALUE: "max-value",
  MIN_LENGTH: "min-length",
  MAX_LENGTH: "max-length",
  PATTERN: "pattern",
  CHECKSUM: "checksum"
};
/**
 * Value-Schema Error
 */
export class ValueSchemaError extends Error {
  /**
   * throw an error
   * @param cause cause of error
   * @param values input/output values
   * @param keyStack path to key that caused error
   * @throws error object
   */
  static raise(cause, values, keyStack) {
    throw new ValueSchemaError(cause, values.input, keyStack);
  }
  /**
   * check whether error is instance of ValueSchemaError or not
   * @param err error to check
   * @returns Yes/No
   */
  static is(err) {
    return err instanceof ValueSchemaError;
  }
  /**
   * constructor
   * @param cause cause of error
   * @param value input value
   * @param keyStack path to key that caused error
   */
  constructor(cause, value, keyStack) {
    super(`${cause}; ${value}; ${keyStack}`);
    this.name = "ValueSchemaError";
    this.cause = cause;
    this.value = value;
    this.keyStack = [...keyStack];
  }
}